==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebComboDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "./type";
import { WebIconDescriptionModule } from "./WebIconDescriptionModule";
import { WebComboListDescriptionModule } from "./WebComboListDescriptionModule";
import { WebComboItemDescriptionModule } from "./WebComboItemDescriptionModule";
import { WebComboHeaderDescriptionModule } from "./WebComboHeaderDescriptionModule";
import { WebInputDescriptionModule } from "./WebInputDescriptionModule";
import { WebComboDescriptionMetadata } from "./WebComboDescriptionMetadata";
/**
 * @hidden
 */
var WebComboDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebComboDescriptionModule, _super);
    function WebComboDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebComboDescriptionModule.register = function (a) {
        WebIconDescriptionModule.register(a);
        WebComboListDescriptionModule.register(a);
        WebComboItemDescriptionModule.register(a);
        WebComboHeaderDescriptionModule.register(a);
        WebInputDescriptionModule.register(a);
        WebComboDescriptionMetadata.d(a);
    };
    WebComboDescriptionModule.$t = markType(WebComboDescriptionModule, 'WebComboDescriptionModule');
    return WebComboDescriptionModule;
}(Base));
export { WebComboDescriptionModule };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebComboDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "./type";
import { WebIconDescriptionModule } from "./WebIconDescriptionModule";
import { WebInputDescriptionModule } from "./WebInputDescriptionModule";
import { WebComboChangeEventArgsDescriptionMetadata } from "./WebComboChangeEventArgsDescriptionMetadata";
import { WebComboDescriptionMetadata } from "./WebComboDescriptionMetadata";
/**
 * @hidden
 */
var WebComboDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebComboDescriptionModule, _super);
    function WebComboDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebComboDescriptionModule.register = function (a) {
        WebIconDescriptionModule.register(a);
        WebInputDescriptionModule.register(a);
        WebComboChangeEventArgsDescriptionMetadata.d(a);
        WebComboDescriptionMetadata.d(a);
    };
    WebComboDescriptionModule.$t = markType(WebComboDescriptionModule, 'WebComboDescriptionModule');
    return WebComboDescriptionModule;
}(Base));
export { WebComboDescriptionModule };
